@@ -1,13 +1,13 @@
 /** 
  * @file bonus.c 
  * @brief Handle gems, bonus and penality 
- * @date 2012-08-26 
+ * @date 2014-10-12
  * @author Jean-Michel Martin de Santero
  * @author Bruno Ethvignot
  * @author Laurent Duperval
  */
 /* 
- * copyright (c) 1998-2014 TLK Games all rights reserved
+ * copyright (c) 1998-2015 TLK Games all rights reserved
  * $Id: bonus.c,v 1.30 2012/08/26 17:09:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
@@ -221,6 +221,26 @@ bonus_free (void)
     }
 }
 
+/*
+ * Disables all gems on the screen
+ */
+void
+bonus_disable_all (void)
+{
+  gem_str *gem;
+  Sint32 i, n;
+  gem = gem_first;
+  if (gem == NULL)
+    {
+      return;
+    }
+  n = num_of_gems;
+  for (i = 0; i < n; i++, gem = gem->next)
+    {
+     bonus_del_gem (gem);
+    }
+}
+
 /**
  * Animate, move and draw the gems
  */
@@ -228,13 +248,14 @@ void
 bonus_handle (void)
 {
   gem_str *gem;
-  Sint32 i;
+  Sint32 i, n;
   gem = gem_first;
   if (gem == NULL)
     {
       return;
     }
-  for (i = 0; i < num_of_gems; i++, gem = gem->next)
+  n = num_of_gems;
+  for (i = 0; i < n; i++, gem = gem->next)
     {
 
 #ifdef UNDER_DEVELOPMENT
