@@ -2,11 +2,11 @@
  * @file config_file.h
  * @brief Handle configuration file 
  * @created 2005-12-12 
- * @date 2013-02-17 
+ * @date 2015-01-10 
  * @author Bruno Ethvignot
  */
 /*
- * copyright (c) 1998-2014 TLK Games all rights reserved
+ * copyright (c) 1998-2015 TLK Games all rights reserved
  * $Id: config_file.h,v 1.11 2012/06/03 17:06:14 gurumeditation Exp $
  *
  * Powermanga is free software; you can redistribute it and/or modify
@@ -52,6 +52,12 @@ extern "C"
     Sint32 scale_x;
     /** 320 or 640 */
     Sint32 resolution;
+    /** Joystick configuration **/
+    Sint32 joy_x_axis;
+    Sint32 joy_y_axis;
+    Sint32 joy_fire;
+    Sint32 joy_option;
+    Sint32 joy_start;
     /** verbose mode leve 1 or 2 if more messages */
     Sint32 verbose;
     /** 0 = easy, 1 = normal or 2 = hard */
