@@ -3,12 +3,12 @@
  *
  * Copyright (C) 2001, 2002, 2003, 2004 Andrea Mazzoleni
  *
- * Powermanga is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Powermanga is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -33,7 +33,7 @@
  */
 
 #if HAVE_CONFIG_H
-#include "../config.h"
+#include <config.h>
 #endif
 
 #include "scale2x.h"
@@ -51,7 +51,7 @@
  * So, enable it only if you are sure to never write directly in video memory.
  */
 /* #define USE_SCALE_RANDOMWRITE */
-
+#ifdef USE_SCALE_RANDOMWRITE
 static inline void scale2x_8_def_whole(scale2x_uint8* restrict dst0, scale2x_uint8* restrict dst1, const scale2x_uint8* restrict src0, const scale2x_uint8* restrict src1, const scale2x_uint8* restrict src2, unsigned count)
 {
 	assert(count >= 2);
@@ -110,6 +110,7 @@ static inline void scale2x_8_def_whole(scale2x_uint8* restrict dst0, scale2x_uin
 		dst1[1] = src1[0];
 	}
 }
+#endif
 
 static inline void scale2x_8_def_border(scale2x_uint8* restrict dst, const scale2x_uint8* restrict src0, const scale2x_uint8* restrict src1, const scale2x_uint8* restrict src2, unsigned count)
 {
@@ -201,6 +202,7 @@ static inline void scale2x_8_def_center(scale2x_uint8* restrict dst, const scale
 	}
 }
 
+#ifdef USE_SCALE_RANDOMWRITE
 static inline void scale2x_16_def_whole(scale2x_uint16* restrict dst0, scale2x_uint16* restrict dst1, const scale2x_uint16* restrict src0, const scale2x_uint16* restrict src1, const scale2x_uint16* restrict src2, unsigned count)
 {
 	assert(count >= 2);
@@ -259,6 +261,7 @@ static inline void scale2x_16_def_whole(scale2x_uint16* restrict dst0, scale2x_u
 		dst1[1] = src1[0];
 	}
 }
+#endif
 
 static inline void scale2x_16_def_border(scale2x_uint16* restrict dst, const scale2x_uint16* restrict src0, const scale2x_uint16* restrict src1, const scale2x_uint16* restrict src2, unsigned count)
 {
@@ -350,6 +353,7 @@ static inline void scale2x_16_def_center(scale2x_uint16* restrict dst, const sca
 	}
 }
 
+#ifdef USE_SCALE_RANDOMWRITE
 static inline void scale2x_32_def_whole(scale2x_uint32* restrict dst0, scale2x_uint32* restrict dst1, const scale2x_uint32* restrict src0, const scale2x_uint32* restrict src1, const scale2x_uint32* restrict src2, unsigned count)
 {
 	assert(count >= 2);
@@ -408,6 +412,7 @@ static inline void scale2x_32_def_whole(scale2x_uint32* restrict dst0, scale2x_u
 		dst1[1] = src1[0];
 	}
 }
+#endif
 
 static inline void scale2x_32_def_border(scale2x_uint32* restrict dst, const scale2x_uint32* restrict src0, const scale2x_uint32* restrict src1, const scale2x_uint32* restrict src2, unsigned count)
 {
@@ -671,7 +676,7 @@ void scale2x4_32_def(scale2x_uint32* dst0, scale2x_uint32* dst1, scale2x_uint32*
 /***************************************************************************/
 /* Scale2x MMX implementation */
 
-#if defined(__GNUC__) && defined(__i386__)
+#if defined(__GNUC__) && (defined(__i386__) || defined(__x86_64__))
 
 /*
  * Apply the Scale2x effect at a single row.
@@ -773,13 +778,13 @@ static inline void scale2x_8_mmx_border(scale2x_uint8* dst, const scale2x_uint8*
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
 /* central runs */
-		"shrl $3, %4\n"
+		"shr $3, %4\n"
 		"jz 1f\n"
 
 		"0:\n"
@@ -835,12 +840,12 @@ static inline void scale2x_8_mmx_border(scale2x_uint8* dst, const scale2x_uint8*
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
-		"decl %4\n"
+		"dec %4\n"
 		"jnz 0b\n"
 		"1:\n"
 
@@ -964,13 +969,13 @@ static inline void scale2x_16_mmx_border(scale2x_uint16* dst, const scale2x_uint
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
 /* central runs */
-		"shrl $2, %4\n"
+		"shr $2, %4\n"
 		"jz 1f\n"
 
 		"0:\n"
@@ -1026,12 +1031,12 @@ static inline void scale2x_16_mmx_border(scale2x_uint16* dst, const scale2x_uint
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
-		"decl %4\n"
+		"dec %4\n"
 		"jnz 0b\n"
 		"1:\n"
 
@@ -1155,13 +1160,13 @@ static inline void scale2x_32_mmx_border(scale2x_uint32* dst, const scale2x_uint
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
 /* central runs */
-		"shrl $1, %4\n"
+		"shr $1, %4\n"
 		"jz 1f\n"
 
 		"0:\n"
@@ -1217,12 +1222,12 @@ static inline void scale2x_32_mmx_border(scale2x_uint32* dst, const scale2x_uint
 		"movq %%mm3, 8(%3)\n"
 
 		/* next */
-		"addl $8, %0\n"
-		"addl $8, %1\n"
-		"addl $8, %2\n"
-		"addl $16, %3\n"
+		"add $8, %0\n"
+		"add $8, %1\n"
+		"add $8, %2\n"
+		"add $16, %3\n"
 
-		"decl %4\n"
+		"dec %4\n"
 		"jnz 0b\n"
 		"1:\n"
 
